# Getting Started

```{todo}
The rest of this documentation needs to be written.
```

This section demonstrates the basic Torii workflow to provide a cursory overview of the language and the toolchain. See the [Tutorials] section for a step-by-step introduction to Torii-USB.

## Prerequisites

Before you get started, you should [install Torii-USB] and its dependencies. You should also install a supported FPGA toolchain.

[Tutorials]: ./tutorials/index.md
[install Torii-USB]: ./install.md
